@@ -23,7 +23,7 @@ use constant DeferredSaveDir => "Defer";
 # method flushStash(OP::Class $class: Str ?$path) {
 sub flushStash {
   my $class = shift;
-  my $path = shift;
+  my $path  = shift;
 
   $path ||= $class->__bulkPath;
 
@@ -31,7 +31,8 @@ sub flushStash {
 
   $class->write('SET FOREIGN_KEY_CHECKS = 0');
 
-  my $rows = $class->write( sprintf q|
+  my $rows = $class->write(
+    sprintf q|
       LOAD DATA INFILE %s
         REPLACE INTO TABLE %s.%s ( %s )
     |,
@@ -52,39 +53,42 @@ sub flushStash {
 
   my $stashedIds = $class->get("__stashedIds");
 
-  $asserts->each( sub {
-    my $key = shift;
+  $asserts->each(
+    sub {
+      my $key = shift;
 
-    my $type = $asserts->{$key};
+      my $type = $asserts->{$key};
 
-    my $oClass = $type->objectClass;
+      my $oClass = $type->objectClass;
 
-    if (
-      $oClass->isa('OP::Array') || $oClass->isa('OP::Hash')
-    ) {
-      my $elementClass = $class->elementClass($key);
+      if ( $oClass->isa('OP::Array') || $oClass->isa('OP::Hash') ) {
+        my $elementClass = $class->elementClass($key);
 
-      if ( $stashedIds ) {
-        $stashedIds->each( sub {
-          my $key = shift;
+        if ($stashedIds) {
+          $stashedIds->each(
+            sub {
+              my $key = shift;
 
-          $elementClass->write( sprintf q|
+              $elementClass->write(
+                sprintf q|
               delete from %s where parentId = %s
             |,
-            $elementClass->tableName,
-            $elementClass->quote( $key )
+                $elementClass->tableName,
+                $elementClass->quote($key)
+              );
+            }
           );
-        } );
 
-        $stashedIds->clear;
+          $stashedIds->clear;
+        }
+
+        $elementClass->flushStash;
       }
-      
-      $elementClass->flushStash;
     }
-  } );
+  );
 
   return $rows;
-};
+}
 
 #
 #
@@ -102,12 +106,12 @@ sub stash {
   if ( !$stashedIds ) {
     $stashedIds = OP::Hash->new;
 
-    $class->set("__stashedIds", $stashedIds);
+    $class->set( "__stashedIds", $stashedIds );
   }
 
   my $now = time;
 
-  $self->{$class->__primaryKey} ||= $self->_newId;
+  $self->{ $class->__primaryKey } ||= $self->_newId;
   $self->{ctime} ||= $now;
   $self->{mtime} = $now;
 
@@ -118,52 +122,55 @@ sub stash {
   #
   my $asserts = $class->asserts;
 
-  $asserts->each( sub {
-    my $key = shift;
+  $asserts->each(
+    sub {
+      my $key = shift;
 
-    my $type = $asserts->{$key};
+      my $type = $asserts->{$key};
 
-    my $oClass = $type->objectClass;
+      my $oClass = $type->objectClass;
 
-    if ( $oClass->isa('OP::Array') ) {
-      my $elementClass = $class->elementClass($key);
+      if ( $oClass->isa('OP::Array') ) {
+        my $elementClass = $class->elementClass($key);
 
-      my $i = 0;
+        my $i = 0;
 
-      for my $value ( @{ $self->{$key} } ) {
-        my $element = $elementClass->new(
-          parentId => $self->key(),
-          elementIndex => $i,
-          elementValue => $value,
-        );
+        for my $value ( @{ $self->{$key} } ) {
+          my $element = $elementClass->new(
+            parentId     => $self->key(),
+            elementIndex => $i,
+            elementValue => $value,
+          );
 
-        $element->stash;
+          $element->stash;
 
-        $i++;
+          $i++;
+        }
       }
-    } elsif ( $oClass->isa('OP::Hash') ) {
-      my $elementClass = $class->elementClass($key);
+      elsif ( $oClass->isa('OP::Hash') ) {
+        my $elementClass = $class->elementClass($key);
 
-      for my $elementKey ( keys %{ $self->{$key} } ) {
-        my $value = $self->{$key}->{$elementKey};
+        for my $elementKey ( keys %{ $self->{$key} } ) {
+          my $value = $self->{$key}->{$elementKey};
 
-        my $element = $elementClass->new(
-          parentId => $self->key(),
-          elementKey => $elementKey,
-          elementValue => $value,
-        );
+          my $element = $elementClass->new(
+            parentId     => $self->key(),
+            elementKey   => $elementKey,
+            elementValue => $value,
+          );
 
-        $element->stash;
+          $element->stash;
+        }
       }
     }
-  } );
+  );
 
   my $path = $class->__bulkPath;
 
-  open(LOG, ">>", $path) || die $@;
+  open( LOG, ">>", $path ) || die $@;
   print LOG $self->_toBulk;
   close(LOG);
-};
+}
 
 #
 #
@@ -175,7 +182,7 @@ sub _prestash {
   #
   # Abstract method, override if needed
   #
-};
+}
 
 #
 # Returns the name of the scratch directory where deferred saves are stashed
@@ -184,8 +191,8 @@ sub _prestash {
 sub __bulkRoot {
   my $class = shift;
 
-  return join("/", scratchRoot, DeferredSaveDir);
-};
+  return join( "/", scratchRoot, DeferredSaveDir );
+}
 
 #
 # Returns the full path to this process's deferred save stash
@@ -194,14 +201,14 @@ sub __bulkRoot {
 sub __bulkPath {
   my $class = shift;
 
-  my $filename = join(".", $class, $$, "log");
+  my $filename = join( ".", $class, $$, "log" );
 
   my $root = $class->__bulkRoot;
 
   mkpath $root if !-d $root;
 
-  return join("/", $root, $filename);
-};
+  return join( "/", $root, $filename );
+}
 
 #
 # http://dev.mysql.com/doc/refman/5.1/en/load-data.html
@@ -220,7 +227,7 @@ sub __escapeBulkValue {
   $value =~ s/\\/\\\\/gs;
 
   return $value;
-};
+}
 
 #
 # Return the names of the columns used for bulk insert
@@ -231,20 +238,22 @@ sub __bulkColumns {
 
   my $asserts = $class->asserts;
 
-  return $asserts->collect( sub {
-    my $key = shift;
+  return $asserts->collect(
+    sub {
+      my $key = shift;
 
-    my $type = $asserts->{$key};
-    my $oClass = $type->objectClass;
+      my $type   = $asserts->{$key};
+      my $oClass = $type->objectClass;
 
-    #
-    #
-    #
-    return if $oClass->isa("OP::Hash") || $oClass->isa("OP::Array");
+      #
+      #
+      #
+      return if $oClass->isa("OP::Hash") || $oClass->isa("OP::Array");
 
-    yield $key;
-  } );
-};
+      yield $key;
+    }
+  );
+}
 
 #
 # Return a tab-delimited row which will be written into the defer stash
@@ -253,28 +262,30 @@ sub __bulkColumns {
 sub _toBulk {
   my $self = shift;
 
-  my $class = $self->class;
+  my $class   = $self->class;
   my $asserts = $class->asserts;
 
-  my $row = $asserts->collect( sub {
-    my $key = shift;
+  my $row = $asserts->collect(
+    sub {
+      my $key = shift;
 
-    my $type = $asserts->{$key};
-    my $oClass = $type->objectClass;
+      my $type   = $asserts->{$key};
+      my $oClass = $type->objectClass;
 
-    #
-    #
-    #
-    return if $oClass->isa("OP::Hash") || $oClass->isa("OP::Array");
+      #
+      #
+      #
+      return if $oClass->isa("OP::Hash") || $oClass->isa("OP::Array");
 
-    my $value = $self->{$key};
+      my $value = $self->{$key};
 
-    yield $class->__escapeBulkValue($value);
+      yield $class->__escapeBulkValue($value);
 
-  } )->join("\t");
+    }
+  )->join("\t");
 
   return "$row\n";
-};
+}
 
 package OP::Persistence;
 
@@ -292,12 +303,13 @@ do {
   *__bulkColumns     = \&OP::Persistence::Bulk::__bulkColumns;
   *__escapeBulkValue = \&OP::Persistence::Bulk::__escapeBulkValue;
 
-  *_prestash         = \&OP::Persistence::Bulk::_prestash;
-  *_toBulk           = \&OP::Persistence::Bulk::_toBulk;
+  *_prestash = \&OP::Persistence::Bulk::_prestash;
+  *_toBulk   = \&OP::Persistence::Bulk::_toBulk;
 };
 
 true;
 __END__
+
 =pod
 
 =head1 NAME
@@ -340,10 +352,10 @@ contain garbage data. This is a very sharp knife.
 =head1 BUGS
 
 Using this mix-in with classes that have attributes possessing
-C<sqlValue> insert/update overrides, such as those descended from
-L<OP::RRNode>, will probably not work as-is. Any necessary logic for
-handling insert/update value overrides may be defined in a class's
-C<_prestash> method, which is called prior to stashing.
+C<sqlValue> insert/update overrides will probably not work as-is.
+Any necessary logic for handling insert/update value overrides may
+be defined in a class's C<_prestash> method, which is called prior
+to stashing.
 
 =head1 SEE ALSO
 
