@@ -12,29 +12,32 @@ use GlobalDBI;
 
 sub columnNames {
   my $class = shift;
-  my $raw = shift;
+  my $raw   = shift;
 
   my $asserts = $class->asserts();
 
-  return $asserts->collect( sub {
-    my $attr = shift;
+  return $asserts->collect(
+    sub {
+      my $attr = shift;
 
-    my $type = $asserts->{$attr};
+      my $type = $asserts->{$attr};
 
-    my $objectClass = $type->objectClass;
+      my $objectClass = $type->objectClass;
 
-    return if $objectClass->isa("OP::Array");
-    return if $objectClass->isa("OP::Hash");
+      return if $objectClass->isa("OP::Array");
+      return if $objectClass->isa("OP::Hash");
 
-    OP::Array::yield($attr);
-  } );
+      OP::Array::yield($attr);
+    }
+  );
 }
 
 sub __doesIdExistStatement {
   my $class = shift;
-  my $id = shift;
+  my $id    = shift;
 
-  return( sprintf q|
+  return (
+    sprintf q|
       SELECT count(*) FROM %s WHERE id = %s
     |,
     $class->tableName,
@@ -44,9 +47,10 @@ sub __doesIdExistStatement {
 
 sub __doesNameExistStatement {
   my $class = shift;
-  my $name = shift;
+  my $name  = shift;
 
-  return( sprintf q|
+  return (
+    sprintf q|
       SELECT count(*) FROM %s WHERE name = %s
     |,
     $class->tableName,
@@ -56,9 +60,10 @@ sub __doesNameExistStatement {
 
 sub __idForNameStatement {
   my $class = shift;
-  my $name = shift;
+  my $name  = shift;
 
-  return( sprintf q|
+  return (
+    sprintf q|
       SELECT %s FROM %s WHERE name = %s
     |,
     $class->__primaryKey(),
@@ -69,9 +74,10 @@ sub __idForNameStatement {
 
 sub __nameForIdStatement {
   my $class = shift;
-  my $id = shift;
+  my $id    = shift;
 
-  return( sprintf q|
+  return (
+    sprintf q|
       SELECT name FROM %s WHERE %s = %s
     |,
     $class->tableName(),
@@ -84,9 +90,7 @@ sub __beginTransaction {
   my $class = shift;
 
   if ( !$OP::Persistence::transactionLevel ) {
-    $class->write(
-      $class->__beginTransactionStatement()
-    );
+    $class->write( $class->__beginTransactionStatement() );
   }
 
   $OP::Persistence::transactionLevel++;
@@ -94,29 +98,23 @@ sub __beginTransaction {
   return $@ ? false : true;
 }
 
-
 sub __rollbackTransaction {
   my $class = shift;
 
-  $class->write(
-    $class->__rollbackTransactionStatement()
-  );
+  $class->write( $class->__rollbackTransactionStatement() );
 
   return $@ ? false : true;
 }
 
-
 sub __commitTransaction {
   my $class = shift;
 
   if ( !$OP::Persistence::transactionLevel ) {
     throw OP::TransactionFailed(
-      "$class->__commitTransaction() called outside of transaction!!!"
-    );
-  } elsif ( $OP::Persistence::transactionLevel == 1 ) {
-    $class->write(
-      $class->__commitTransactionStatement()
-    );
+      "$class->__commitTransaction() called outside of transaction!!!" );
+  }
+  elsif ( $OP::Persistence::transactionLevel == 1 ) {
+    $class->write( $class->__commitTransactionStatement() );
   }
 
   $OP::Persistence::transactionLevel--;
@@ -124,28 +122,24 @@ sub __commitTransaction {
   return $@ ? false : true;
 }
 
-
 sub __beginTransactionStatement {
   my $class = shift;
 
   return "BEGIN;\n";
 }
 
-
 sub __commitTransactionStatement {
   my $class = shift;
 
   return "COMMIT;\n";
 }
 
-
 sub __rollbackTransactionStatement {
   my $class = shift;
 
   return "ROLLBACK;\n";
 }
 
-
 sub __schema {
   my $class = shift;
 
@@ -154,15 +148,14 @@ sub __schema {
   #
   my $primaryKey = $class->__primaryKey();
 
-  throw OP::PrimaryKeyMissing(
-    "$class has no __primaryKey set, please fix"
-  ) if !$primaryKey;
+  throw OP::PrimaryKeyMissing( "$class has no __primaryKey set, please fix" )
+    if !$primaryKey;
 
   my $asserts = $class->asserts();
 
   throw OP::PrimaryKeyMissing(
-    "$class did not assert __primaryKey $primaryKey"
-  ) if !exists $asserts->{$primaryKey};
+    "$class did not assert __primaryKey $primaryKey" )
+    if !exists $asserts->{$primaryKey};
 
   #
   # Tack on any UNIQUE secondary keys at the end of the schema
@@ -190,11 +183,10 @@ sub __schema {
 
     next if !$type;
 
-    my $statement = $class->__statementForColumn(
-      $attribute, $type, $foreign, $unique
-    );
+    my $statement =
+      $class->__statementForColumn( $attribute, $type, $foreign, $unique );
 
-    $inlineAttribs->push( sprintf('  %s', $statement) )
+    $inlineAttribs->push( sprintf( '  %s', $statement ) )
       if $statement;
   }
 
@@ -205,7 +197,6 @@ sub __schema {
   return $schema->join("\n");
 }
 
-
 sub __concatNameStatement {
   my $class = shift;
 
@@ -218,11 +209,13 @@ sub __concatNameStatement {
   my @uniqueAttrs;
 
   if ( ref $uniqueness ) {
-    @uniqueAttrs = @{ $uniqueness };
-  } elsif ( $uniqueness && $uniqueness ne '1' ) {
+    @uniqueAttrs = @{$uniqueness};
+  }
+  elsif ( $uniqueness && $uniqueness ne '1' ) {
     @uniqueAttrs = $uniqueness;
-  } else {
-    return join(".", $class->tableName, "name") . " as __name";
+  }
+  else {
+    return join( ".", $class->tableName, "name" ) . " as __name";
 
     # @uniqueAttrs = "name";
   }
@@ -231,11 +224,12 @@ sub __concatNameStatement {
   # For each attribute that "name" is keyed with, include the
   # value in a display name. If the value is an ID, look up the name.
   #
-  for my $extAttr ( @uniqueAttrs ) {
+  for my $extAttr (@uniqueAttrs) {
+
     #
     # Get the class
     #
-    my $type = $asserts->{ $extAttr };
+    my $type = $asserts->{$extAttr};
 
     if ( $type->objectClass()->isa("OP::ExtID") ) {
       my $extClass = $type->memberClass();
@@ -243,31 +237,32 @@ sub __concatNameStatement {
       my $tableName = $extClass->tableName();
 
       #
-      # Method calls itself-- 
+      # Method calls itself--
       #
       # I don't think this will ever infinitely loop,
       # since we use constraints (see query)
       #
       my $subSel = $extClass->__concatNameStatement()
-        || sprintf('%s.name', $tableName);
+        || sprintf( '%s.name', $tableName );
 
-      $concatAttrs->push( sprintf q|
+      $concatAttrs->push(
+        sprintf q|
           ( SELECT %s FROM %s WHERE %s.id = %s )
         |,
         $subSel, $tableName, $tableName, $extAttr
       );
 
-    } else {
+    }
+    else {
       $concatAttrs->push($extAttr);
     }
   }
 
-  $concatAttrs->push(join(".", $class->tableName, "name"));
+  $concatAttrs->push( join( ".", $class->tableName, "name" ) );
 
   return if $concatAttrs->isEmpty();
 
-  my $select = sprintf
-    'concat(%s) as __name', $concatAttrs->join(', " / ", ');
+  my $select = sprintf 'concat(%s) as __name', $concatAttrs->join(', " / ", ');
 
   return $select;
 }
@@ -279,16 +274,16 @@ sub __serialType {
 }
 
 sub __statementForColumn {
-  my $class = shift;
+  my $class     = shift;
   my $attribute = shift;
-  my $type = shift;
-  my $foreign = shift; # Not handled by Generic
-  my $unique = shift;  # Not handled by Generic - see $uniqueInline instead
+  my $type      = shift;
+  my $foreign   = shift;    # Not handled by Generic
+  my $unique    = shift;    # Not handled by Generic - see $uniqueInline instead
+
+  if ( $type->objectClass()->isa("OP::Hash")
+    || $type->objectClass()->isa("OP::Array") )
+  {
 
-  if (
-    $type->objectClass()->isa("OP::Hash")
-     || $type->objectClass()->isa("OP::Array")
-  ) {
     #
     # Value lives in a link table, not in this class's table
     #
@@ -298,7 +293,7 @@ sub __statementForColumn {
   #
   # Using this key as an AUTO_INCREMENT primary key?
   #
-  return join(" ", $attribute, $class->__serialType)
+  return join( " ", $attribute, $class->__serialType )
     if $type->serial;
 
   #
@@ -317,8 +312,8 @@ sub __statementForColumn {
   # Same with PRIMARY KEY, MySQL likes them at the bottom, other DBs
   # want it to be inline.
   #
-  my $primaryInline = ( $class->__primaryKey eq $attribute )
-    ? "PRIMARY KEY" : "";
+  my $primaryInline =
+    ( $class->__primaryKey eq $attribute ) ? "PRIMARY KEY" : "";
 
   #
   # Permitting NULL/undef values for this key?
@@ -327,27 +322,29 @@ sub __statementForColumn {
 
   my $fragment = OP::Array->new();
 
-  if (
-    defined $type->default
+  if ( defined $type->default
     && $datatype !~ /^text/i
-    && $datatype !~ /^blob/i
-  ) {
+    && $datatype !~ /^blob/i )
+  {
+
     #
     # A "default" value was specified by a subtyping rule,
     # so plug it in to the database table schema:
     #
-    my $quotedDefault = $class->quote($type->default);
+    my $quotedDefault = $class->quote( $type->default );
 
     $fragment->push( $attribute, $datatype, 'DEFAULT', $quotedDefault );
-  } else {
+  }
+  else {
+
     #
     # No default() was specified:
     #
     $fragment->push( $attribute, $datatype );
   }
 
-  $fragment->push($notNull) if $notNull;
-  $fragment->push($uniqueInline) if $uniqueInline;
+  $fragment->push($notNull)       if $notNull;
+  $fragment->push($uniqueInline)  if $uniqueInline;
   $fragment->push($primaryInline) if $primaryInline;
 
   return $fragment->join(" ");
@@ -363,7 +360,6 @@ sub __dropTable {
   return $class->write($query);
 }
 
-
 sub __createTable {
   my $class = shift;
 
@@ -372,31 +368,28 @@ sub __createTable {
   return $class->write($query);
 }
 
-
 sub __selectRowStatement {
   my $class = shift;
-  my $id = shift;
+  my $id    = shift;
 
-  return sprintf(q| SELECT %s FROM %s WHERE %s = %s |,
-    $class->__selectColumnNames->join(", "),
-    $class->tableName(),
-    $class->__primaryKey(),
-    $class->quote($id)
+  return sprintf(
+    q| SELECT %s FROM %s WHERE %s = %s |,
+    $class->__selectColumnNames->join(", "), $class->tableName(),
+    $class->__primaryKey(),                  $class->quote($id)
   );
 }
 
-
 sub __allNamesStatement {
   my $class = shift;
 
-  return sprintf(q| SELECT name FROM %s |, $class->tableName());
+  return sprintf( q| SELECT name FROM %s |, $class->tableName() );
 }
 
-
 sub __allIdsStatement {
   my $class = shift;
 
-  return sprintf( q|
+  return sprintf(
+    q|
       SELECT %s FROM %s ORDER BY name
     |,
     $class->__primaryKey(),
@@ -406,7 +399,7 @@ sub __allIdsStatement {
 
 sub __wrapWithReconnect {
   my $class = shift;
-  my $sub = shift;
+  my $sub   = shift;
 
   warn "$class\::__wrapWithReconnect not implemented";
 
@@ -431,7 +424,18 @@ sub __init {
 sub __updateColumnNames {
   my $class = shift;
 
-  return $class->columnNames;
+  my $priKey = $class->__primaryKey;
+
+  return $class->columnNames->collect(
+    sub {
+      my $name = shift;
+
+      return if $name eq $priKey;
+      return if $name eq 'ctime';
+
+      OP::Array::yield($name);
+    }
+  );
 }
 
 sub __insertColumnNames {
@@ -443,15 +447,18 @@ sub __insertColumnNames {
   # Omit "id" from the SQL statement if we're using auto-increment
   #
   if ( $class->asserts->{$priKey}->isa("OP::Type::Serial") ) {
-    return $class->columnNames->collect( sub {
-      my $name = shift;
+    return $class->columnNames->collect(
+      sub {
+        my $name = shift;
 
-      return if $name eq $priKey;
+        return if $name eq $priKey;
 
-      OP::Array::yield($name);
-    } );
+        OP::Array::yield($name);
+      }
+    );
 
-  } else {
+  }
+  else {
     return $class->columnNames;
   }
 }
@@ -461,42 +468,45 @@ sub __selectColumnNames {
 
   my $asserts = $class->asserts();
 
-  return $class->columnNames->collect( sub {
-    my $attr = shift;
+  return $class->columnNames->collect(
+    sub {
+      my $attr = shift;
 
-    my $type = $asserts->{$attr};
+      my $type = $asserts->{$attr};
 
-    my $objectClass = $type->objectClass;
+      my $objectClass = $type->objectClass;
 
-    return if $objectClass->isa("OP::Array");
-    return if $objectClass->isa("OP::Hash");
+      return if $objectClass->isa("OP::Array");
+      return if $objectClass->isa("OP::Hash");
 
-    if (
-      $objectClass->isa("OP::DateTime")
-       && ( $type->columnType eq 'DATETIME' )
-    ) {
-      # OP::Array::yield("UNIX_TIMESTAMP($attr) AS $attr");
-      OP::Array::yield( $class->__quoteDatetimeSelect($attr) );
+      if ( $objectClass->isa("OP::DateTime")
+        && ( $type->columnType eq 'DATETIME' ) )
+      {
 
-    } else {
-      OP::Array::yield($attr);
+        # OP::Array::yield("UNIX_TIMESTAMP($attr) AS $attr");
+        OP::Array::yield( $class->__quoteDatetimeSelect($attr) );
+
+      }
+      else {
+        OP::Array::yield($attr);
+      }
     }
-  } );
+  );
 }
 
 sub __quoteDatetimeInsert {
   my $class = shift;
   my $value = shift;
 
-die;
+  die;
   return $value;
 }
 
 sub __quoteDatetimeSelect {
   my $class = shift;
-  my $attr = shift;
+  my $attr  = shift;
 
-die;
+  die;
   return $attr;
 }
 
@@ -504,7 +514,7 @@ die;
 #
 #
 sub _quotedValues {
-  my $self = shift;
+  my $self     = shift;
   my $isUpdate = shift;
 
   my $class = $self->class();
@@ -513,69 +523,78 @@ sub _quotedValues {
 
   my $asserts = $class->asserts();
 
-  my $columns = $isUpdate ?
-    $class->__updateColumnNames : $class->__insertColumnNames;
+  my $columns =
+    $isUpdate ? $class->__updateColumnNames : $class->__insertColumnNames;
 
-  $columns->each( sub {
-    my $key = shift;
+  $columns->each(
+    sub {
+      my $key = shift;
 
-    my $value = $self->get($key);
+      my $value = $self->get($key);
 
-    my $quotedValue;
+      my $quotedValue;
 
-    my $type = $asserts->{$key};
-    return if !$type;
+      my $type = $asserts->{$key};
+      return if !$type;
 
-    if ( $type->sqlInsertValue && $OP::Persistence::ForceInsertSQL ) {
-      $quotedValue = $type->sqlInsertValue;
+      if ( $type->sqlInsertValue && $OP::Persistence::ForceInsertSQL ) {
+        $quotedValue = $type->sqlInsertValue;
 
-    } elsif ( $type->sqlUpdateValue && $OP::Persistence::ForceUpdateSQL ) {
-      $quotedValue = $type->sqlUpdateValue;
+      }
+      elsif ( $type->sqlUpdateValue && $OP::Persistence::ForceUpdateSQL ) {
+        $quotedValue = $type->sqlUpdateValue;
 
-    } elsif ( $type->sqlValue() ) {
-      $quotedValue = $type->sqlValue();
+      }
+      elsif ( $type->sqlValue() ) {
+        $quotedValue = $type->sqlValue();
 
-    } elsif ( $type->optional() && !defined($value) ) {
-      $quotedValue = 'NULL';
+      }
+      elsif ( $type->optional() && !defined($value) ) {
+        $quotedValue = 'NULL';
 
-    } elsif ( !defined($value) || ( !ref($value) && $value eq '' ) ) {
-      $quotedValue = "''";
+      }
+      elsif ( !defined($value) || ( !ref($value) && $value eq '' ) ) {
+        $quotedValue = "''";
 
-    } elsif (
-      !ref($value) || ( ref($value) && overload::Overloaded($value) )
-    ) {
-      if ( !UNIVERSAL::isa($value, $type->objectClass) ) {
-        #
-        # Sorry, but you're an object now.
-        #
-        $value = $type->objectClass->new( Clone::clone($value) );
+      }
+      elsif ( !ref($value) || ( ref($value) && overload::Overloaded($value) ) )
+      {
+        if ( !UNIVERSAL::isa( $value, $type->objectClass ) ) {
+
+          #
+          # Sorry, but you're an object now.
+          #
+          $value = $type->objectClass->new( Clone::clone($value) );
+        }
+
+        if ( $type->objectClass->isa("OP::DateTime")
+          && $type->columnType eq 'DATETIME' )
+        {
+          $quotedValue = $class->__quoteDatetimeInsert($value);
+        }
+        else {
+          $quotedValue = $class->quote($value);
+        }
+      }
+      elsif ( ref($value) ) {
+        my $dumpedValue =
+          UNIVERSAL::can( $value, "toYaml" )
+          ? $value->toYaml
+          : YAML::Syck::Dump($value);
+
+        chomp($dumpedValue);
+
+        $quotedValue = $class->quote($dumpedValue);
       }
 
-      if (
-        $type->objectClass->isa("OP::DateTime")
-          && $type->columnType eq 'DATETIME'
-      ) {
-        $quotedValue = $class->__quoteDatetimeInsert($value);
-      } else {
-        $quotedValue = $class->quote($value);
+      if ($isUpdate) {
+        $values->push("  $key = $quotedValue");
+      }
+      else {    # Is Insert
+        $values->push($quotedValue);
       }
-    } elsif ( ref($value) ) {
-      my $dumpedValue =
-        UNIVERSAL::can($value, "toYaml")
-        ? $value->toYaml
-        : YAML::Syck::Dump($value);
-
-      chomp($dumpedValue);
-
-      $quotedValue = $class->quote($dumpedValue);
     }
-
-    if ( $isUpdate ) {
-      $values->push( "  $key = $quotedValue" )
-    } else { # Is Insert
-      $values->push( $quotedValue );
-    }
-  } );
+  );
 
   return $values;
 }
@@ -585,11 +604,10 @@ sub _updateRowStatement {
 
   my $class = $self->class();
 
-  my $statement = sprintf( q| UPDATE %s SET %s WHERE %s = %s; |,
-    $class->tableName(),
-    $self->_quotedValues(true)->join(",\n"),
-    $class->__primaryKey(),
-    $class->quote( $self->key() )
+  my $statement = sprintf(
+    q| UPDATE %s SET %s WHERE %s = %s; |,
+    $class->tableName(),    $self->_quotedValues(true)->join(",\n"),
+    $class->__primaryKey(), $class->quote( $self->key() )
   );
 
   return $statement;
@@ -600,7 +618,8 @@ sub _insertRowStatement {
 
   my $class = $self->class();
 
-  return sprintf( q| INSERT INTO %s (%s) VALUES (%s); |,
+  return sprintf(
+    q| INSERT INTO %s (%s) VALUES (%s); |,
     $class->tableName(),
     $class->__insertColumnNames->join(', '),
     $self->_quotedValues(false)->join(', '),
@@ -613,16 +632,13 @@ sub _deleteRowStatement {
   my $idKey = $self->class()->__primaryKey();
 
   unless ( defined $self->{$idKey} ) {
-    throw OP::ObjectIsAnonymous( "Can't delete an object with no ID" );
+    throw OP::ObjectIsAnonymous("Can't delete an object with no ID");
   }
 
   my $class = $self->class();
 
   return sprintf( q| DELETE FROM %s WHERE %s = %s |,
-    $class->tableName(),
-    $idKey,
-    $class->quote($self->{$idKey})
-  );
+    $class->tableName(), $idKey, $class->quote( $self->{$idKey} ) );
 }
 
 true;
