@@ -8,6 +8,7 @@
 # which accompanies this distribution, and is available at
 # http://opensource.org/licenses/cpl1.0.txt
 #
+
 =pod
 
 =head1 NAME
@@ -55,11 +56,9 @@ sub assert {
   my $class = shift;
   my @rules = @_;
 
-  my %parsed = OP::Type::__parseTypeArgs(
-    OP::Type::isInt, @rules
-  );
+  my %parsed = OP::Type::__parseTypeArgs( OP::Type::isInt, @rules );
 
-  $parsed{serial} = true;
+  $parsed{serial}   = true;
   $parsed{optional} = true;
   $parsed{columnType} ||= 'INTEGER';
 
